# RestOC
A python 3 set of modules used for setting up REST microservices

# Install
```
pip install rest-oc
```

# Requires
RestOC requires python 3.10 or higher

# Documentation

http://ouroboroscoding.com/rest-oc/
